// Windows client configuration header

#ifndef CONFIG_H_INCLUDED
#define CONFIG_H_INCLUDED

// include common Windows header
#include "config_common.h"

// we're using SDL_Mixer
#define HAVE_LIBSDL_MIXER 1

#endif
